# command

```shell
pipx install pwsh-utils
say -t 'hello world' # cowsay
os # operating system
dt # datetime
ts # timestamp
ms # milliseconds
nano # nanoseconds
ev 'PATH' # echo environment variable
uuid # uuid
btc-eth # 从币安获取比特币和以太坊的价格 支持socks5代理设置,设置环境变量->HTTP_PROXY=socks5h://127.0.0.1:7890
rmw "./1.png" --colors 5 # 简单的去水印
tg-login # telegram user or bot login and get sessionString
```
